from unittest import TestCase

from strikebot.updates import parse_update


def _build_payload(body_html: str) -> dict[str, str]:
	return {"body_html": body_html}


class UpdateParsingTests(TestCase):
	def test_successful_counts(self):
		pu = parse_update(_build_payload("<div>12,345,678 spaghetti</div>"), None, "")
		self.assertEqual(pu.number, 12345678)
		self.assertFalse(pu.deletable)

		pu = parse_update(_build_payload("<div><p>0</p><br/>oz</div>"), None, "")
		self.assertEqual(pu.number, 0)
		self.assertFalse(pu.deletable)

		pu = parse_update(_build_payload("<div>121 345 621</div>"), 121, "")
		self.assertEqual(pu.number, 121)
		self.assertFalse(pu.deletable)

		pu = parse_update(_build_payload("28 336 816"), 28336816, "")
		self.assertEqual(pu.number, 28336816)
		self.assertTrue(pu.deletable)

	def test_non_counts(self):
		pu = parse_update(_build_payload("<div><table><tbody><tr><td>zoo</td></tr></tbody></table></div>"), None, "")
		self.assertFalse(pu.count_attempt)
		self.assertFalse(pu.deletable)

	def test_typos(self):
		pu = parse_update(_build_payload("<span>v9</span>"), 888, "")
		self.assertIsNone(pu.number)
		self.assertTrue(pu.count_attempt)

		pu = parse_update(_build_payload("<div>v11.585 Empire</div>"), None, "")
		self.assertIsNone(pu.number)
		self.assertTrue(pu.count_attempt)
		self.assertFalse(pu.deletable)

		pu = parse_update(_build_payload("<div>11, 585, 22 </div>"), 11_585_202, "")
		self.assertIsNone(pu.number)
		self.assertTrue(pu.count_attempt)
		self.assertTrue(pu.deletable)

		pu = parse_update(_build_payload("<span>0490499</span>"), 4999, "")
		self.assertIsNone(pu.number)
		self.assertTrue(pu.count_attempt)
